<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwich Mean tíð (Abidjan)',
        'Africa/Accra' => 'Greenwich Mean tíð (Accra)',
        'Africa/Addis_Ababa' => 'Eysturafrika tíð (Addis Ababa)',
        'Africa/Algiers' => 'Miðevropa tíð (Algiers)',
        'Africa/Asmera' => 'Eysturafrika tíð (Asmara)',
        'Africa/Asmara' => 'Eysturafrika tíð (Asmara)',
        'Africa/Bamako' => 'Greenwich Mean tíð (Bamako)',
        'Africa/Bangui' => 'Vesturafrika tíð (Bangui)',
        'Africa/Banjul' => 'Greenwich Mean tíð (Banjul)',
        'Africa/Bissau' => 'Greenwich Mean tíð (Bissau)',
        'Africa/Blantyre' => 'Miðafrika tíð (Blantyre)',
        'Africa/Brazzaville' => 'Vesturafrika tíð (Brazzaville)',
        'Africa/Bujumbura' => 'Miðafrika tíð (Bujumbura)',
        'Africa/Cairo' => 'Eysturevropa tíð (Cairo)',
        'Africa/Casablanca' => 'Vesturevropa tíð (Casablanca)',
        'Africa/Ceuta' => 'Miðevropa tíð (Ceuta)',
        'Africa/Conakry' => 'Greenwich Mean tíð (Conakry)',
        'Africa/Dakar' => 'Greenwich Mean tíð (Dakar)',
        'Africa/Dar_es_Salaam' => 'Eysturafrika tíð (Dar es Salaam)',
        'Africa/Djibouti' => 'Eysturafrika tíð (Djibuti)',
        'Africa/Douala' => 'Vesturafrika tíð (Douala)',
        'Africa/El_Aaiun' => 'Vesturevropa tíð (El Aaiún)',
        'Africa/Freetown' => 'Greenwich Mean tíð (Freetown)',
        'Africa/Gaborone' => 'Miðafrika tíð (Gaborone)',
        'Africa/Harare' => 'Miðafrika tíð (Harare)',
        'Africa/Johannesburg' => 'Suðurafrika vanlig tíð (Johannesburg)',
        'Africa/Juba' => 'Miðafrika tíð (Juba)',
        'Africa/Kampala' => 'Eysturafrika tíð (Kampala)',
        'Africa/Khartoum' => 'Miðafrika tíð (Khartoum)',
        'Africa/Kigali' => 'Miðafrika tíð (Kigali)',
        'Africa/Kinshasa' => 'Vesturafrika tíð (Kinshasa)',
        'Africa/Lagos' => 'Vesturafrika tíð (Lagos)',
        'Africa/Libreville' => 'Vesturafrika tíð (Libreville)',
        'Africa/Lome' => 'Greenwich Mean tíð (Lomé)',
        'Africa/Luanda' => 'Vesturafrika tíð (Luanda)',
        'Africa/Lubumbashi' => 'Miðafrika tíð (Lubumbashi)',
        'Africa/Lusaka' => 'Miðafrika tíð (Lusaka)',
        'Africa/Malabo' => 'Vesturafrika tíð (Malabo)',
        'Africa/Maputo' => 'Miðafrika tíð (Maputo)',
        'Africa/Maseru' => 'Suðurafrika vanlig tíð (Maseru)',
        'Africa/Mbabane' => 'Suðurafrika vanlig tíð (Mbabane)',
        'Africa/Mogadishu' => 'Eysturafrika tíð (Mogadishu)',
        'Africa/Monrovia' => 'Greenwich Mean tíð (Monrovia)',
        'Africa/Nairobi' => 'Eysturafrika tíð (Nairobi)',
        'Africa/Ndjamena' => 'Vesturafrika tíð (N’Djamena)',
        'Africa/Niamey' => 'Vesturafrika tíð (Niamey)',
        'Africa/Nouakchott' => 'Greenwich Mean tíð (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwich Mean tíð (Ouagadougou)',
        'Africa/Porto-Novo' => 'Vesturafrika tíð (Porto-Novo)',
        'Africa/Sao_Tome' => 'Greenwich Mean tíð (São Tomé)',
        'Africa/Tripoli' => 'Eysturevropa tíð (Tripoli)',
        'Africa/Tunis' => 'Miðevropa tíð (Tunis)',
        'Africa/Windhoek' => 'Miðafrika tíð (Windhoek)',
        'America/Adak' => 'Hawaii-Aleutian tíð (Adak)',
        'America/Anchorage' => 'Alaska tíð (Anchorage)',
        'America/Anguilla' => 'Atlantic tíð (Anguilla)',
        'America/Antigua' => 'Atlantic tíð (Antigua)',
        'America/Araguaina' => 'Brasilia tíð (Araguaína)',
        'America/Argentina/La_Rioja' => 'Argentina tíð (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Argentina tíð (Río Gallegos)',
        'America/Argentina/Salta' => 'Argentina tíð (Salta)',
        'America/Argentina/San_Juan' => 'Argentina tíð (San Juan)',
        'America/Argentina/San_Luis' => 'Argentina tíð (San Luis)',
        'America/Argentina/Tucuman' => 'Argentina tíð (Tucumán)',
        'America/Argentina/Ushuaia' => 'Argentina tíð (Ushuaia)',
        'America/Aruba' => 'Atlantic tíð (Aruba)',
        'America/Asuncion' => 'Paraguai tíð (Asunción)',
        'America/Bahia' => 'Brasilia tíð (Bahia)',
        'America/Bahia_Banderas' => 'Central tíð (Bahia Banderas)',
        'America/Barbados' => 'Atlantic tíð (Barbados)',
        'America/Belem' => 'Brasilia tíð (Belém)',
        'America/Belize' => 'Central tíð (Belis)',
        'America/Blanc-Sablon' => 'Atlantic tíð (Blanc-Sablon)',
        'America/Boa_Vista' => 'Amasona tíð (Boa Vista)',
        'America/Bogota' => 'Kolombia tíð (Bogotá)',
        'America/Boise' => 'Mountain tíð (Boise)',
        'America/Buenos_Aires' => 'Argentina tíð (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Argentina tíð (Buenos Aires)',
        'America/Cambridge_Bay' => 'Mountain tíð (Cambridge Bay)',
        'America/Campo_Grande' => 'Amasona tíð (Campo Grande)',
        'America/Cancun' => 'Eastern tíð (Cancun)',
        'America/Caracas' => 'Venesuela tíð (Caracas)',
        'America/Catamarca' => 'Argentina tíð (Catamarca)',
        'America/Argentina/Catamarca' => 'Argentina tíð (Catamarca)',
        'America/Cayenne' => 'Franska Gujana tíð (Cayenne)',
        'America/Cayman' => 'Eastern tíð (Cayman)',
        'America/Chicago' => 'Central tíð (Chicago)',
        'America/Chihuahua' => 'Central tíð (Chihuahua)',
        'America/Ciudad_Juarez' => 'Mountain tíð (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Eastern tíð (Atikokan)',
        'America/Atikokan' => 'Eastern tíð (Atikokan)',
        'America/Cordoba' => 'Argentina tíð (Córdoba)',
        'America/Argentina/Cordoba' => 'Argentina tíð (Córdoba)',
        'America/Costa_Rica' => 'Central tíð (Kosta Rika)',
        'America/Coyhaique' => 'Kili tíð (Coyhaique)',
        'America/Creston' => 'Mountain tíð (Creston)',
        'America/Cuiaba' => 'Amasona tíð (Cuiabá)',
        'America/Curacao' => 'Atlantic tíð (Curaçao)',
        'America/Danmarkshavn' => 'Greenwich Mean tíð (Danmarkshavn)',
        'America/Dawson' => 'Yukon tíð (Dawson)',
        'America/Dawson_Creek' => 'Mountain tíð (Dawson Creek)',
        'America/Denver' => 'Mountain tíð (Denver)',
        'America/Detroit' => 'Eastern tíð (Detroit)',
        'America/Dominica' => 'Atlantic tíð (Dominica)',
        'America/Edmonton' => 'Mountain tíð (Edmonton)',
        'America/Eirunepe' => 'Brasil tíð (Eirunepé)',
        'America/El_Salvador' => 'Central tíð (El Salvador)',
        'America/Fort_Nelson' => 'Mountain tíð (Fort Nelson)',
        'America/Fortaleza' => 'Brasilia tíð (Fortaleza)',
        'America/Glace_Bay' => 'Atlantic tíð (Glace Bay)',
        'America/Godthab' => 'Grønland tíð (Nuuk)',
        'America/Nuuk' => 'Grønland tíð (Nuuk)',
        'America/Goose_Bay' => 'Atlantic tíð (Goose Bay)',
        'America/Grand_Turk' => 'Eastern tíð (Grand Turk)',
        'America/Grenada' => 'Atlantic tíð (Grenada)',
        'America/Guadeloupe' => 'Atlantic tíð (Guadeloupe)',
        'America/Guatemala' => 'Central tíð (Guatemala)',
        'America/Guayaquil' => 'Ekvador tíð (Guayaquil)',
        'America/Guyana' => 'Gujana tíð (Guyana)',
        'America/Halifax' => 'Atlantic tíð (Halifax)',
        'America/Havana' => 'Cuba tíð (Havana)',
        'America/Hermosillo' => 'Mexican Pacific tíð (Hermosillo)',
        'America/Indiana/Knox' => 'Central tíð (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Eastern tíð (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Eastern tíð (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Central tíð (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Eastern tíð (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Eastern tíð (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Eastern tíð (Winamac, Indiana)',
        'America/Indianapolis' => 'Eastern tíð (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Eastern tíð (Indianapolis)',
        'America/Inuvik' => 'Mountain tíð (Inuvik)',
        'America/Iqaluit' => 'Eastern tíð (Iqaluit)',
        'America/Jamaica' => 'Eastern tíð (Jamaika)',
        'America/Jujuy' => 'Argentina tíð (Jujuy)',
        'America/Argentina/Jujuy' => 'Argentina tíð (Jujuy)',
        'America/Juneau' => 'Alaska tíð (Juneau)',
        'America/Kentucky/Monticello' => 'Eastern tíð (Monticello, Kentucky)',
        'America/Kralendijk' => 'Atlantic tíð (Kralendijk)',
        'America/La_Paz' => 'Bolivia tíð (La Paz)',
        'America/Lima' => 'Peru tíð (Lima)',
        'America/Los_Angeles' => 'Pacific tíð (Los Angeles)',
        'America/Louisville' => 'Eastern tíð (Louisville)',
        'America/Kentucky/Louisville' => 'Eastern tíð (Louisville)',
        'America/Lower_Princes' => 'Atlantic tíð (Lower Prince’s Quarter)',
        'America/Maceio' => 'Brasilia tíð (Maceió)',
        'America/Managua' => 'Central tíð (Managua)',
        'America/Manaus' => 'Amasona tíð (Manaus)',
        'America/Marigot' => 'Atlantic tíð (Marigot)',
        'America/Martinique' => 'Atlantic tíð (Martinique)',
        'America/Matamoros' => 'Central tíð (Matamoros)',
        'America/Mazatlan' => 'Mexican Pacific tíð (Mazatlán)',
        'America/Mendoza' => 'Argentina tíð (Mendoza)',
        'America/Argentina/Mendoza' => 'Argentina tíð (Mendoza)',
        'America/Menominee' => 'Central tíð (Menominee)',
        'America/Merida' => 'Central tíð (Merida)',
        'America/Metlakatla' => 'Alaska tíð (Metlakatla)',
        'America/Mexico_City' => 'Central tíð (Ciudad de México)',
        'America/Miquelon' => 'St. Pierre & Miquelon tíð (Saint-Pierre)',
        'America/Moncton' => 'Atlantic tíð (Moncton)',
        'America/Monterrey' => 'Central tíð (Monterrey)',
        'America/Montevideo' => 'Uruguai tíð (Montevideo)',
        'America/Montserrat' => 'Atlantic tíð (Montserrat)',
        'America/Nassau' => 'Eastern tíð (Nassau)',
        'America/New_York' => 'Eastern tíð (New York)',
        'America/Nome' => 'Alaska tíð (Nome)',
        'America/Noronha' => 'Fernando de Noronha tíð',
        'America/North_Dakota/Beulah' => 'Central tíð (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Central tíð (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Central tíð (New Salem, North Dakota)',
        'America/Ojinaga' => 'Central tíð (Ojinaga)',
        'America/Panama' => 'Eastern tíð (Panama)',
        'America/Paramaribo' => 'Surinam tíð (Paramaribo)',
        'America/Phoenix' => 'Mountain tíð (Phoenix)',
        'America/Port-au-Prince' => 'Eastern tíð (Port-au-Prince)',
        'America/Port_of_Spain' => 'Atlantic tíð (Port of Spain)',
        'America/Porto_Velho' => 'Amasona tíð (Porto Velho)',
        'America/Puerto_Rico' => 'Atlantic tíð (Puerto Riko)',
        'America/Punta_Arenas' => 'Kili tíð (Punta Arenas)',
        'America/Rankin_Inlet' => 'Central tíð (Rankin Inlet)',
        'America/Recife' => 'Brasilia tíð (Recife)',
        'America/Regina' => 'Central tíð (Regina)',
        'America/Resolute' => 'Central tíð (Resolute)',
        'America/Rio_Branco' => 'Brasil tíð (Rio Branco)',
        'America/Santarem' => 'Brasilia tíð (Santarém)',
        'America/Santiago' => 'Kili tíð (Santiago)',
        'America/Santo_Domingo' => 'Atlantic tíð (Santo Domingo)',
        'America/Sao_Paulo' => 'Brasilia tíð (São Paulo)',
        'America/Scoresbysund' => 'Grønland tíð (Ittoqqortoormiit)',
        'America/Sitka' => 'Alaska tíð (Sitka)',
        'America/St_Barthelemy' => 'Atlantic tíð (St. Barthélemy)',
        'America/St_Johns' => 'Newfoundland tíð (St. John’s)',
        'America/St_Kitts' => 'Atlantic tíð (St. Kitts)',
        'America/St_Lucia' => 'Atlantic tíð (St. Lucia)',
        'America/St_Thomas' => 'Atlantic tíð (St. Thomas)',
        'America/St_Vincent' => 'Atlantic tíð (St. Vincent)',
        'America/Swift_Current' => 'Central tíð (Swift Current)',
        'America/Tegucigalpa' => 'Central tíð (Tegucigalpa)',
        'America/Thule' => 'Atlantic tíð (Thule)',
        'America/Tijuana' => 'Pacific tíð (Tijuana)',
        'America/Toronto' => 'Eastern tíð (Toronto)',
        'America/Tortola' => 'Atlantic tíð (Tortola)',
        'America/Vancouver' => 'Pacific tíð (Vancouver)',
        'America/Whitehorse' => 'Yukon tíð (Whitehorse)',
        'America/Winnipeg' => 'Central tíð (Winnipeg)',
        'America/Yakutat' => 'Alaska tíð (Yakutat)',
        'Antarctica/Casey' => 'vestur Avstralia tíð (Casey)',
        'Antarctica/Davis' => 'Davis tíð',
        'Antarctica/DumontDUrville' => 'Dumont-d’Urville tíð',
        'Antarctica/Macquarie' => 'eystur Avstralia tíð (Macquarie)',
        'Antarctica/Mawson' => 'Mawson tíð',
        'Antarctica/McMurdo' => 'Nýsæland tíð (McMurdo)',
        'Antarctica/Palmer' => 'Kili tíð (Palmer)',
        'Antarctica/Rothera' => 'Rothera tíð',
        'Antarctica/Syowa' => 'Syowa tíð (Showa)',
        'Antarctica/Troll' => 'Greenwich Mean tíð (Troll)',
        'Antarctica/Vostok' => 'Vostok tíð',
        'Arctic/Longyearbyen' => 'Miðevropa tíð (Longyearbyen)',
        'Asia/Aden' => 'Arabisk tíð (Aden)',
        'Asia/Almaty' => 'Kasakstan tíð (Almaty)',
        'Asia/Amman' => 'Eysturevropa tíð (Amman)',
        'Asia/Anadyr' => 'Russland tíð (Anadyr)',
        'Asia/Aqtau' => 'Kasakstan tíð (Aqtau)',
        'Asia/Aqtobe' => 'Kasakstan tíð (Aqtobe)',
        'Asia/Ashgabat' => 'Turkmenistan tíð (Ashgabat)',
        'Asia/Atyrau' => 'Kasakstan tíð (Atyrau)',
        'Asia/Baghdad' => 'Arabisk tíð (Baghdad)',
        'Asia/Bahrain' => 'Arabisk tíð (Barein)',
        'Asia/Baku' => 'Aserbadjan tíð (Baku)',
        'Asia/Bangkok' => 'Indokina tíð (Bangkok)',
        'Asia/Barnaul' => 'Krasnoyarsk tíð (Barnaul)',
        'Asia/Beirut' => 'Eysturevropa tíð (Beirut)',
        'Asia/Bishkek' => 'Kirgisia tíð (Bishkek)',
        'Asia/Brunei' => 'Brunei Darussalam tíð',
        'Asia/Calcutta' => 'India tíð (Kolkata)',
        'Asia/Kolkata' => 'India tíð (Kolkata)',
        'Asia/Chita' => 'Yakutsk tíð (Chita)',
        'Asia/Colombo' => 'India tíð (Colombo)',
        'Asia/Damascus' => 'Eysturevropa tíð (Damascus)',
        'Asia/Dhaka' => 'Bangladesj tíð (Dhaka)',
        'Asia/Dili' => 'Eysturtimor tíð (Dili)',
        'Asia/Dubai' => 'Gulf vanlig tíð (Dubai)',
        'Asia/Dushanbe' => 'Tadsjikistan tíð (Dushanbe)',
        'Asia/Famagusta' => 'Eysturevropa tíð (Famagusta)',
        'Asia/Gaza' => 'Eysturevropa tíð (Gasa)',
        'Asia/Hebron' => 'Eysturevropa tíð (Hebron)',
        'Asia/Hong_Kong' => 'Hong Kong tíð',
        'Asia/Hovd' => 'Hovd tíð (Khovd)',
        'Asia/Irkutsk' => 'Irkutsk tíð',
        'Asia/Jakarta' => 'Vestur Indonesia tíð (Jakarta)',
        'Asia/Jayapura' => 'Eystur Indonesia tíð (Jayapura)',
        'Asia/Jerusalem' => 'Ísrael tíð (Jerusalem)',
        'Asia/Kabul' => 'Afganistan tíð (Kabul)',
        'Asia/Kamchatka' => 'Russland tíð (Kamchatka)',
        'Asia/Karachi' => 'Pakistan tíð (Karachi)',
        'Asia/Katmandu' => 'Nepal tíð (Kathmandu)',
        'Asia/Kathmandu' => 'Nepal tíð (Kathmandu)',
        'Asia/Khandyga' => 'Yakutsk tíð (Khandyga)',
        'Asia/Krasnoyarsk' => 'Krasnoyarsk tíð',
        'Asia/Kuala_Lumpur' => 'Malaisia tíð (Kuala Lumpur)',
        'Asia/Kuching' => 'Malaisia tíð (Kuching)',
        'Asia/Kuwait' => 'Arabisk tíð (Kuvait)',
        'Asia/Macau' => 'Kina tíð (Makao)',
        'Asia/Magadan' => 'Magadan tíð',
        'Asia/Makassar' => 'Mið Indonesia tíð (Makassar)',
        'Asia/Manila' => 'Filipsoyggjar tíð (Manila)',
        'Asia/Muscat' => 'Gulf vanlig tíð (Muscat)',
        'Asia/Nicosia' => 'Eysturevropa tíð (Nicosia)',
        'Asia/Novokuznetsk' => 'Krasnoyarsk tíð (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Krasnoyarsk tíð (Novosibirsk)',
        'Asia/Omsk' => 'Omsk tíð',
        'Asia/Oral' => 'Kasakstan tíð (Oral)',
        'Asia/Phnom_Penh' => 'Indokina tíð (Phnom Penh)',
        'Asia/Pontianak' => 'Vestur Indonesia tíð (Pontianak)',
        'Asia/Pyongyang' => 'Korea tíð (Pyongyang)',
        'Asia/Qatar' => 'Arabisk tíð (Qatar)',
        'Asia/Qostanay' => 'Kasakstan tíð (Kostanay)',
        'Asia/Qyzylorda' => 'Kasakstan tíð (Qyzylorda)',
        'Asia/Rangoon' => 'Myanmar (Burma) tíð (Rangoon)',
        'Asia/Yangon' => 'Myanmar (Burma) tíð (Rangoon)',
        'Asia/Riyadh' => 'Arabisk tíð (Riyadh)',
        'Asia/Saigon' => 'Indokina tíð (Ho Chi Minh)',
        'Asia/Ho_Chi_Minh' => 'Indokina tíð (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Magadan tíð (Sakhalin)',
        'Asia/Samarkand' => 'Usbekistan tíð (Samarkand)',
        'Asia/Seoul' => 'Korea tíð (Seoul)',
        'Asia/Shanghai' => 'Kina tíð (Shanghai)',
        'Asia/Singapore' => 'Singapor tíð',
        'Asia/Srednekolymsk' => 'Magadan tíð (Srednekolymsk)',
        'Asia/Taipei' => 'Taipei tíð',
        'Asia/Tashkent' => 'Usbekistan tíð (Tashkent)',
        'Asia/Tbilisi' => 'Georgia tíð (Tbilisi)',
        'Asia/Tehran' => 'Iran tíð (Teheran)',
        'Asia/Thimphu' => 'Butan tíð (Thimphu)',
        'Asia/Tokyo' => 'Japan tíð (Tokyo)',
        'Asia/Tomsk' => 'Krasnoyarsk tíð (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulan Bator tíð (Ulaanbaatar)',
        'Asia/Urumqi' => 'Kina tíð (Ürümqi)',
        'Asia/Ust-Nera' => 'Vladivostok tíð (Ust-Nera)',
        'Asia/Vientiane' => 'Indokina tíð (Vientiane)',
        'Asia/Vladivostok' => 'Vladivostok tíð',
        'Asia/Yakutsk' => 'Yakutsk tíð',
        'Asia/Yekaterinburg' => 'Yekaterinburg tíð',
        'Asia/Yerevan' => 'Armenia tíð (Yerevan)',
        'Atlantic/Azores' => 'Azorurnar tíð',
        'Atlantic/Bermuda' => 'Atlantic tíð (Bermuda)',
        'Atlantic/Canary' => 'Vesturevropa tíð (Canarias)',
        'Atlantic/Cape_Verde' => 'Grønhøvdaoyggjar tíð',
        'Atlantic/Faeroe' => 'Vesturevropa tíð (Føroyar)',
        'Atlantic/Faroe' => 'Vesturevropa tíð (Føroyar)',
        'Atlantic/Madeira' => 'Vesturevropa tíð (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwich Mean tíð (Reykjavík)',
        'Atlantic/South_Georgia' => 'Suðurgeorgiaoyggjar tíð',
        'Atlantic/St_Helena' => 'Greenwich Mean tíð (St. Helena)',
        'Atlantic/Stanley' => 'Falklandsoyggjar tíð (Stanley)',
        'Australia/Adelaide' => 'mið Avstralia tíð (Adelaide)',
        'Australia/Brisbane' => 'eystur Avstralia tíð (Brisbane)',
        'Australia/Broken_Hill' => 'mið Avstralia tíð (Broken Hill)',
        'Australia/Darwin' => 'mið Avstralia tíð (Darwin)',
        'Australia/Eucla' => 'miðvestur Avstralia tíð (Eucla)',
        'Australia/Hobart' => 'eystur Avstralia tíð (Hobart)',
        'Australia/Lindeman' => 'eystur Avstralia tíð (Lindeman)',
        'Australia/Lord_Howe' => 'Lord Howe tíð',
        'Australia/Melbourne' => 'eystur Avstralia tíð (Melbourne)',
        'Australia/Perth' => 'vestur Avstralia tíð (Perth)',
        'Australia/Sydney' => 'eystur Avstralia tíð (Sydney)',
        'Etc/GMT' => 'Greenwich Mean tíð',
        'Etc/UTC' => 'Samskipað heimstíð',
        'Europe/Amsterdam' => 'Miðevropa tíð (Amsterdam)',
        'Europe/Andorra' => 'Miðevropa tíð (Andorra)',
        'Europe/Astrakhan' => 'Russland tíð (Astrakhan)',
        'Europe/Athens' => 'Eysturevropa tíð (Aten)',
        'Europe/Belgrade' => 'Miðevropa tíð (Beograd)',
        'Europe/Berlin' => 'Miðevropa tíð (Berlin)',
        'Europe/Bratislava' => 'Miðevropa tíð (Bratislava)',
        'Europe/Brussels' => 'Miðevropa tíð (Bruxelles)',
        'Europe/Bucharest' => 'Eysturevropa tíð (Bukarest)',
        'Europe/Budapest' => 'Miðevropa tíð (Budapest)',
        'Europe/Busingen' => 'Miðevropa tíð (Büsingen)',
        'Europe/Chisinau' => 'Eysturevropa tíð (Chișinău)',
        'Europe/Copenhagen' => 'Miðevropa tíð (Keypmannahavn)',
        'Europe/Dublin' => 'Greenwich Mean tíð (Dublin)',
        'Europe/Gibraltar' => 'Miðevropa tíð (Gibraltar)',
        'Europe/Guernsey' => 'Greenwich Mean tíð (Guernsey)',
        'Europe/Helsinki' => 'Eysturevropa tíð (Helsinki)',
        'Europe/Isle_of_Man' => 'Greenwich Mean tíð (Isle of Man)',
        'Europe/Istanbul' => 'Turkaland tíð (Istanbul)',
        'Europe/Jersey' => 'Greenwich Mean tíð (Jersey)',
        'Europe/Kaliningrad' => 'Eysturevropa tíð (Kaliningrad)',
        'Europe/Kiev' => 'Eysturevropa tíð (Kiev)',
        'Europe/Kyiv' => 'Eysturevropa tíð (Kiev)',
        'Europe/Kirov' => 'Moskva tíð (Kirov)',
        'Europe/Lisbon' => 'Vesturevropa tíð (Lissabon)',
        'Europe/Ljubljana' => 'Miðevropa tíð (Ljubljana)',
        'Europe/London' => 'Greenwich Mean tíð (London)',
        'Europe/Luxembourg' => 'Miðevropa tíð (Luksemborg)',
        'Europe/Madrid' => 'Miðevropa tíð (Madrid)',
        'Europe/Malta' => 'Miðevropa tíð (Malta)',
        'Europe/Mariehamn' => 'Eysturevropa tíð (Mariehamn)',
        'Europe/Minsk' => 'Moskva tíð (Minsk)',
        'Europe/Monaco' => 'Miðevropa tíð (Monako)',
        'Europe/Moscow' => 'Moskva tíð',
        'Europe/Oslo' => 'Miðevropa tíð (Oslo)',
        'Europe/Paris' => 'Miðevropa tíð (Paris)',
        'Europe/Podgorica' => 'Miðevropa tíð (Podgorica)',
        'Europe/Prague' => 'Miðevropa tíð (Prag)',
        'Europe/Riga' => 'Eysturevropa tíð (Riga)',
        'Europe/Rome' => 'Miðevropa tíð (Rom)',
        'Europe/Samara' => 'Russland tíð (Samara)',
        'Europe/San_Marino' => 'Miðevropa tíð (San Marino)',
        'Europe/Sarajevo' => 'Miðevropa tíð (Sarajevo)',
        'Europe/Saratov' => 'Russland tíð (Saratov)',
        'Europe/Simferopol' => 'Moskva tíð (Simferopol)',
        'Europe/Skopje' => 'Miðevropa tíð (Skopje)',
        'Europe/Sofia' => 'Eysturevropa tíð (Sofia)',
        'Europe/Stockholm' => 'Miðevropa tíð (Stokkhólm)',
        'Europe/Tallinn' => 'Eysturevropa tíð (Tallinn)',
        'Europe/Tirane' => 'Miðevropa tíð (Tirana)',
        'Europe/Ulyanovsk' => 'Russland tíð (Ulyanovsk)',
        'Europe/Vaduz' => 'Miðevropa tíð (Vaduz)',
        'Europe/Vatican' => 'Miðevropa tíð (Vatikanið)',
        'Europe/Vienna' => 'Miðevropa tíð (Wien)',
        'Europe/Vilnius' => 'Eysturevropa tíð (Vilnius)',
        'Europe/Volgograd' => 'Moskva tíð (Volgograd)',
        'Europe/Warsaw' => 'Miðevropa tíð (Varsjava)',
        'Europe/Zagreb' => 'Miðevropa tíð (Zagreb)',
        'Europe/Zurich' => 'Miðevropa tíð (Zürich)',
        'Indian/Antananarivo' => 'Eysturafrika tíð (Antananarivo)',
        'Indian/Chagos' => 'Indiahav tíð (Chagos)',
        'Indian/Christmas' => 'Jólaoyggj tíð (Christmas)',
        'Indian/Cocos' => 'Kokosoyggjar tíð (Cocos)',
        'Indian/Comoro' => 'Eysturafrika tíð (Comores)',
        'Indian/Kerguelen' => 'Fronsku sunnaru landaøki og Antarktis tíð (Kerguelen)',
        'Indian/Mahe' => 'Seyskelloyggjar tíð (Mahé)',
        'Indian/Maldives' => 'Maldivoyggjar tíð',
        'Indian/Mauritius' => 'Móritius tíð',
        'Indian/Mayotte' => 'Eysturafrika tíð (Mayotte)',
        'Indian/Reunion' => 'Réunion tíð',
        'Pacific/Apia' => 'Apia tíð',
        'Pacific/Auckland' => 'Nýsæland tíð (Auckland)',
        'Pacific/Bougainville' => 'Papua Nýguinea tíð (Bougainville)',
        'Pacific/Chatham' => 'Chatham tíð',
        'Pacific/Easter' => 'Páskaoyggin tíð (Easter)',
        'Pacific/Efate' => 'Vanuatu tíð (Efate)',
        'Pacific/Enderbury' => 'Phoenixoyggjar tíð (Canton)',
        'Pacific/Kanton' => 'Phoenixoyggjar tíð (Canton)',
        'Pacific/Fakaofo' => 'Tokelau tíð (Fakaofo)',
        'Pacific/Fiji' => 'Fiji tíð',
        'Pacific/Funafuti' => 'Tuvalu tíð (Funafuti)',
        'Pacific/Galapagos' => 'Galapagos tíð (Galápagos)',
        'Pacific/Gambier' => 'Gambier tíð',
        'Pacific/Guadalcanal' => 'Salomonoyggjar tíð (Guadalcanal)',
        'Pacific/Guam' => 'Chamorro vanlig tíð (Guam)',
        'Pacific/Honolulu' => 'Hawaii-Aleutian vanlig tíð (Honolulu)',
        'Pacific/Kiritimati' => 'Lineoyggjar tíð (Kiritimati)',
        'Pacific/Kosrae' => 'Kosrae tíð',
        'Pacific/Kwajalein' => 'Marshalloyggjar tíð (Kwajalein)',
        'Pacific/Majuro' => 'Marshalloyggjar tíð (Majuro)',
        'Pacific/Marquesas' => 'Marquesas tíð',
        'Pacific/Midway' => 'Samoa tíð (Midway)',
        'Pacific/Nauru' => 'Nauru tíð',
        'Pacific/Niue' => 'Niue tíð',
        'Pacific/Norfolk' => 'Norfolkoyggj tíð',
        'Pacific/Noumea' => 'Nýkaledónia tíð (Nouméa)',
        'Pacific/Pago_Pago' => 'Samoa tíð (Pago Pago)',
        'Pacific/Palau' => 'Palau tíð',
        'Pacific/Pitcairn' => 'Pitcairnoyggjar tíð',
        'Pacific/Ponape' => 'Ponape tíð (Pohnpei)',
        'Pacific/Pohnpei' => 'Ponape tíð (Pohnpei)',
        'Pacific/Port_Moresby' => 'Papua Nýguinea tíð (Port Moresby)',
        'Pacific/Rarotonga' => 'Cooksoyggjar tíð (Rarotonga)',
        'Pacific/Saipan' => 'Chamorro vanlig tíð (Saipan)',
        'Pacific/Tahiti' => 'Tahiti tíð',
        'Pacific/Tarawa' => 'Gilbertoyggjar tíð (Tarawa)',
        'Pacific/Tongatapu' => 'Tonga tíð (Tongatapu)',
        'Pacific/Truk' => 'Chuuk tíð',
        'Pacific/Chuuk' => 'Chuuk tíð',
        'Pacific/Wake' => 'Wakeoyggj tíð',
        'Pacific/Wallis' => 'Wallis- og Futunaoyggjar tíð (Wallis & Futuna)',
    ],
    'Meta' => [],
];
